==> opennms-dao-mock-16.0.2-sources.jar: org/opennms/netmgt/dao/mock/MockRrdDao.java <==
/*******************************************************************************
 * This file is part of OpenNMS(R).
 *
 * Copyright (C) 2013-2014 The OpenNMS Group, Inc.
 * OpenNMS(R) is Copyright (C) 1999-2014 The OpenNMS Group, Inc.
 *
 * OpenNMS(R) is a registered trademark of The OpenNMS Group, Inc.
 *
 * OpenNMS(R) is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as published
 * by the Free Software Foundation, either version 3 of the License,
 * or (at your option) any later version.
 *
 * OpenNMS(R) is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with OpenNMS(R).  If not, see:
 *      http://www.gnu.org/licenses/
 *
 * For more information contact:
 *     OpenNMS(R) Licensing <license@opennms.org>
 *     http://www.opennms.org/
 *     http://www.opennms.com/
 *******************************************************************************/

package org.opennms.netmgt.dao.mock;

import java.io.File;
import java.io.InputStream;

import org.opennms.netmgt.dao.api.RrdDao;
import org.opennms.netmgt.model.OnmsAttribute;
import org.springframework.dao.DataAccessException;

public class MockRrdDao implements RrdDao {

    @Override
    public double getPrintValue(OnmsAttribute attribute, String cf, long start, long end) {
        throw new UnsupportedOperationException("Not yet implemented!");
    }

    @Override
    public double[] getPrintValues(OnmsAttribute attribute, String rraConsolidationFunction, long startTimeInMillis, long endTimeInMillis, String... printFunctions) {
        throw new UnsupportedOperationException("Not yet implemented!");
    }

    @Override
    public InputStream createGraph(String command, File workDir) {
        throw new UnsupportedOperationException("Not yet implemented!");
    }

    @Override
    public int getGraphTopOffsetWithText() {
        throw new UnsupportedOperationException("Not yet implemented!");
    }

    @Override
    public int getGraphLeftOffset() {
        throw new UnsupportedOperationException("Not yet implemented!");
    }

    @Override
    public int getGraphRightOffset() {
        throw new UnsupportedOperationException("Not yet implemented!");
    }

    @Override
    public Double getLastFetchValue(OnmsAttribute attribute, int interval) throws DataAccessException {
        throw new UnsupportedOperationException("Not yet implemented!");
    }

    @Override
    public Double getLastFetchValue(OnmsAttribute attribute, int interval, int range) throws DataAccessException {
        throw new UnsupportedOperationException("Not yet implemented!");
    }

}

==> opennms-dao-mock-17.0.0-20150709.223024-81-sources.jar: org/opennms/netmgt/dao/mock/MockRrdDao.java <==
/*******************************************************************************
 * This file is part of OpenNMS(R).
 *
 * Copyright (C) 2013-2014 The OpenNMS Group, Inc.
 * OpenNMS(R) is Copyright (C) 1999-2014 The OpenNMS Group, Inc.
 *
 * OpenNMS(R) is a registered trademark of The OpenNMS Group, Inc.
 *
 * OpenNMS(R) is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as published
 * by the Free Software Foundation, either version 3 of the License,
 * or (at your option) any later version.
 *
 * OpenNMS(R) is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with OpenNMS(R).  If not, see:
 *      http://www.gnu.org/licenses/
 *
 * For more information contact:
 *     OpenNMS(R) Licensing <license@opennms.org>
 *     http://www.opennms.org/
 *     http://www.opennms.com/
 *******************************************************************************/

package org.opennms.netmgt.dao.mock;

import java.io.InputStream;

import org.opennms.netmgt.dao.api.RrdDao;
import org.opennms.netmgt.model.OnmsAttribute;
import org.springframework.dao.DataAccessException;

public class MockRrdDao implements RrdDao {

    @Override
    public double getPrintValue(OnmsAttribute attribute, String cf, long start, long end) {
        throw new UnsupportedOperationException("Not yet implemented!");
    }

    @Override
    public double[] getPrintValues(OnmsAttribute attribute, String rraConsolidationFunction, long startTimeInMillis, long endTimeInMillis, String... printFunctions) {
        throw new UnsupportedOperationException("Not yet implemented!");
    }

    @Override
    public InputStream createGraph(String command) {
        throw new UnsupportedOperationException("Not yet implemented!");
    }

    @Override
    public Double getLastFetchValue(OnmsAttribute attribute, int interval) throws DataAccessException {
        throw new UnsupportedOperationException("Not yet implemented!");
    }

    @Override
    public Double getLastFetchValue(OnmsAttribute attribute, int interval, int range) throws DataAccessException {
        throw new UnsupportedOperationException("Not yet implemented!");
    }

}
